<h2>stock3.cfm</h2>

<p>This page shows an example of a four web service requests to retrieve four stock quotes,
using CFTHREAD to run the web service requests simultaneously.</p>

<p>Turn on Debug Output and note the page execution time, which should be faster than stock2.cfm,
and much closer to the time it took stock1.cfm to execute a single request (normally around 500ms).</p>

<!--- run first three quotes on separate threads --->
<cfthread name="Variables.ko">
	<cfreturn GetStockQuote("KO")>
</cfthread>

<cfthread name="Variables.beas">
	<cfreturn GetStockQuote("BEAS")>
</cfthread>

<cfthread name="Variables.msft">
	<cfreturn GetStockQuote("MSFT")>
</cfthread>

<!--- run RHAT on the main (request) thread --->
<cfset Variables.rhat = GetStockQuote("RHAT")>

<!--- wait for the other three threads to finish --->
<cfjoin thread="Variables.ko">
<cfjoin thread="Variables.beas">
<cfjoin thread="Variables.msft">

<cfoutput>
<table border>
<th>Company</th>
<th>Stock Price</th>
<th>Quote Time</th>
<tr>
	<td>Coca-Cola</td>
	<td>#Variables.ko.returnVariable.Price#</td>
	<td>#Variables.ko.returnVariable.Time#</td>
</tr>
<tr>
	<td>BEA</td>
	<td>#Variables.beas.returnVariable.Price#</td>
	<td>#Variables.beas.returnVariable.Time#</td>
</tr>
<tr>
	<td>Microsoft</td>
	<td>#Variables.msft.returnVariable.Price#</td>
	<td>#Variables.msft.returnVariable.Time#</td>
</tr>
<tr>
	<td>Red Hat</td>
	<td>#Variables.rhat.Price#</td>
	<td>#Variables.rhat.Time#</td>
</tr>
</table>
</cfoutput>

<cffunction name="GetStockQuote" returntype="struct" output="false">
	<cfargument name="tickerSymbol" type="string" required="true">
	
	<cfset var structQuote = StructNew()>

	<cftry>
		<cfinvoke webservice="http://www.webservicex.net/stockquote.asmx?WSDL"
			method="GetQuote" symbol="#Arguments.tickerSymbol#"
			returnvariable="strQuoteXML" timeout="2">
		
		<cfset var objQuote = xmlParse( strQuoteXML )>
		
		<cfset structQuote.price = objQuote.StockQuotes.Stock.Last.XMLText>
		<cfset structQuote.time = objQuote.StockQuotes.Stock.Time.XMLText>
		
		<cfcatch>
			<cfset structQuote.price = "ERROR!">
			<cfset structQuote.time = "ERROR!">
		</cfcatch>
	</cftry>
	
	<cfreturn structQuote>
</cffunction>