<cfcomponent output="false">
	<cfset this.name = "stock">

	<cffunction name="onApplicationStart" returnType="boolean" output="false">
		<!--- initialize stock quotes the first time through --->
		<cfset GetAllQuotes()>
		
		<!--- save thread variables in Application scope for onApplicationEnd --->
		<cfthread name="application.stockThread">
			<cflog type="information" text="Stock Thread Started">
		
			<cfset Application.isActive = true>
			<!--- update stock quotes every 10 seconds until Application ends --->
			<cfloop condition="#application.isActive#">
				<cfpause interval="10">
				<cfset GetAllQuotes()>
				<cflog type="information" text="Stock Quotes Updated">
			</cfloop>
			
			<cflog type="information" text="Stock Thread Ended">
		</cfthread>
		
		<cfreturn true>
	</cffunction>

	<cffunction name="onApplicationEnd" returnType="void" output="false">
		<cfargument name="applicationScope" required="true">
		<!--- signal the stock thread to terminate --->
		<cfset ApplicationScope.isActive = false>
		<!--- interrupt (wake up) the stock thread --->
		<cfinterrupt thread="applicationScope.stockThread">
		<!--- wait for the stock thread to terminate --->
		<cfjoin thread="applicationScope.stockThread">
	</cffunction>

	<cffunction name="onError">
		<cfargument name="exception" required="true">
		<cfargument name="eventname" type="string" required="true">
		<!--- log all errors --->
		<cflog type="error" text="Event Name: #Arguments.Eventname#" >
		<cflog type="error" text="Message: #Arguments.Exception.message#">
	</cffunction>

	<cffunction name="GetAllQuotes" access="private" returntype="void" output="false">
		<cfset Application.ko = GetStockQuote( "KO" )>
		<cfset Application.beas = GetStockQuote( "BEAS" )>
		<cfset Application.msft = GetStockQuote( "MSFT" )>
		<cfset Application.rhat = GetStockQuote( "RHAT" )>
	</cffunction>
	
	<cffunction name="GetStockQuote" returntype="struct" output="false">
		<cfargument name="tickerSymbol" type="string" required="true">
		
		<cfset var structQuote = StructNew()>
	
		<cftry>
			<cfinvoke webservice="http://www.webservicex.net/stockquote.asmx?WSDL"
				method="GetQuote" symbol="#Arguments.tickerSymbol#"
				returnvariable="strQuoteXML" timeout="2">
			
			<cfset var objQuote = xmlParse( strQuoteXML )>
			
			<cfset structQuote.price = objQuote.StockQuotes.Stock.Last.XMLText>
			<cfset structQuote.time = objQuote.StockQuotes.Stock.Time.XMLText>
			
			<cfcatch>
				<cfset structQuote.price = "ERROR!">
				<cfset structQuote.time = "ERROR!">
			</cfcatch>
		</cftry>
		
		<cfreturn structQuote>
	</cffunction>
</cfcomponent>