<!---
	DirectoryListener
	
	This interface must be implemented by DirectoryWatcher listeners. Event
	handlers are invoked when files are added, changed, or deleted in
	watched directories.
	
	This has been tested on BlueDragon 7.0 beta2.
	
	vgb	10/25/2006	Created
--->
<cfcomponent type="interface">
	
	<!---
		onAdd( fileName, lastModified )
		
		Invoked when a file is added to a watched directory. The "fileName" argument
		contains the full physical path to the added file; the "lastModifiedDate"
		argument contains the file modification date.
	--->
	<cffunction name="onAdd" access="public" returntype="void">
		<cfargument name="fileName" type="string" required="true">
		<cfargument name="lastModified" type="date" required="true">
	</cffunction>
	
	<!---
		onChange( fileName, lastModified )
		
		Invoked when a file in a watched directory is modified. The "fileName" argument
		contains the full physical path to the modified file; the "lastModifiedDate"
		argument contains the file modification date.
	--->
	<cffunction name="onChange" access="public" returntype="void">
		<cfargument name="fileName" type="string" required="true">
		<cfargument name="lastModified" type="date" required="true">
	</cffunction>
	
	<!---
		onDelete( fileName )
		
		Invoked when a file is deleted from a watched directory. The "fileName" argument
		contains the full physical path to the deleted file.
	--->
	<cffunction name="onDelete" access="public" returntype="void">
		<cfargument name="fileName" type="string" required="true">
	</cffunction>

</cfcomponent>