<h2>BlueDragon 7.0 DirectoryWatcher Example</h2>

<p>This example uses the CFTHREAD tag introduced in BlueDragon 7.0 to implement functionality
equivalent to the the CFMX 7 DirectoryWatcher event gateway. This example consists of the
following files (see the comments in each file for additional details):</p>
<ul>
<p><li>DirectoryWatcher.cfc - this CFC implements a generic directory watcher with which other CFCs
can register to watch specific directories. Initializing a DirectoryWatcher instance via its
init() method causes a background thread to be created via the CFTHREAD tag. Only one DirectoryWatcher
instance may be initialized per BlueDragon instance.</li></p>

<p><li>DirectoryListener.cfc - this CFC defines the interface that must be implemented by any
CFC that wants to register with the DirectoryWatcher to watch a specific directory.</li></p>

<p><li>ImageListener.cfc - this CFC implements the DirectoryListener interface and registers
with the DirectoryWatcher to watch the "image" subdirectory of the current directory. Any images
that are copied to the watched directory are resized to be no larger than 250 pixels high by
250 pixels wide. The ImageListener uses the CFIMAGE tag to resize images.</li></p>

<p><li>Application.cfc - the onApplicationStart does the following: (1) create and initialize a
DirectoryWatcher instance; (2) create a ImageListener instance; and, (3) register the ImageListener
with the DirectoryWatcher to watch the "images" subdirectory of the current directory.</li></p>
</ul>

<p>If you have any questions regarding this example, please contact
	<a href="mailto:josh@newatlanta.com">josh@newatlanta.com</a>.</p>

<cfset Variables.threadRunning = False>
<cfset Variables.threads = getAllThreads()>

<cfloop from="1" to="#arrayLen(Variables.threads)#" index="Variables.loopIndex">
	<cfset Variables.currentThread = Variables.threads[Variables.loopIndex]>
	<cfif (Variables.currentThread.name EQ "DirectoryWatcher") AND threadIsAlive(Variables.currentThread)>
		<cfset Variables.threadRunning = true>
		<h4>DirectoryWatcher thread running time: <cfoutput>#timeSpanFormat(threadRunningTime(currentThread))#</cfoutput></h4>
	</cfif>
</cfloop>

<cfif NOT Variables.threadRunning>
	<h4>DirectoryWatcher thread is not running.</h4>
</cfif>

<cffunction name="timeSpanFormat" returntype="string" output="false">
	<cfargument name="ms" type="numeric" required="true">
	
	<cfset var HOUR = 3600000>
	<cfset var MINUTE = 60000>
	<cfset var SECOND =  1000>
	
	<cfset var hours = 0>
	<cfset var minutes = 0>
	<cfset var seconds = 0>
	
	<cfset hours = ms \ HOUR>
	<cfset ms = ms - (hours * HOUR)>
	
	<cfset minutes = ms \ MINUTE>
	<cfset ms = ms - (minutes * MINUTE)>
	
	<cfset seconds = ms \ SECOND>
	<cfset ms = ms - (seconds * SECOND)>
	
	<cfreturn numberFormat(hours, "00") & ":" & numberFormat(minutes, "00") & ":" & numberFormat(seconds, "00") & "." & numberFormat(ms, "000")>
</cffunction>